import { openDatabase } from "react-native-sqlite-storage";
const reactNativeBackend = (initOpts) => ({ dbName, stopped$ }) => {
  let db;
  return {
    async initialize() {
      db = await openDatabase({
        name: initOpts.name(dbName),
        location: initOpts.location
      });
      stopped$.subscribe(() => {
        if (!db) {
          return;
        }
        void db.close();
      });
    },
    async execQueries(queries, opts) {
      if (!db) {
        throw new Error(`Failed to run queries: ${queries.map((q) => q.text).join(" ")}, db not initialized`);
      }
      const result = [];
      for (const q of queries) {
        const startTime = new Date().getTime();
        result.push((await db.executeSql(q.text, q.values))[0].rows.raw());
        const end = new Date().getTime();
        if (!opts.log.suppress) {
          console.info(`[${dbName}]${opts.log.transactionId ? `[tr_id=${opts.log.transactionId.slice(0, 6)}]` : ""} ` + queries.map((it) => it.text).join(" ") + " Time: " + ((end - startTime) / 1e3).toFixed(4));
        }
      }
      return result;
    }
  };
};
export { reactNativeBackend };
//# sourceMappingURL=index.es.js.map
